==> 1.0.1.tar.gz: lib/src/core/widgets/filters/ModernFormFilterWithCheckboxIten.dart <==
part of modern_form_core;

class ModernFormFilterWithCheckboxIten extends StatelessWidget {
  final List<String?>? suggestions;
  final String? bottomSheetLabelText;
  final String? buttonText;
  final void Function(List<String?> selecteds)? onChanged;
  final List<String?>? initialValue;
  final Future<void> Function()? onTap;
  final bool? forceMenu;
  final bool? moveEnable;

  const ModernFormFilterWithCheckboxIten({
    Key? key,
    this.suggestions,
    this.bottomSheetLabelText,
    this.onChanged,
    this.initialValue,
    this.buttonText,
    this.onTap,
    this.forceMenu,
    this.moveEnable,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    bool _moveEnable = moveEnable != null && moveEnable!;
    return Column(
      children: <Widget>[
        Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            ModernFormFilterTextListItens(
              itens: initialValue,
              iconData: _moveEnable ? Icons.edit : null,
              onTapCloseIten: (index, c) async {
                List<String> _s = List<String>.from(initialValue!);

                if (_moveEnable) {
                  SecondOption? option = await showSecondOption(
                      c, [SecondOption.Move, SecondOption.Delete]);
                  if (option != null) {
                    switch (option) {
                      case SecondOption.Delete:
                        _s.removeAt(index);
                        break;
                      case SecondOption.Move:
                        int? newIndex = await showMoveTo(
                            c, (initialValue?.length ?? 0), index);
                        if (newIndex != null) {
                          String iten = _s[index];
                          _s.removeAt(index);
                          _s.insert(newIndex, iten);
                        }
                        break;
                      default:
                        break;
                    }
                  }
                } else {
                  _s.removeAt(index);
                }
                if (onChanged != null) {
                  onChanged!(_s);
                }
              },
            ),
            SizedBox(height: ScreenUtil().setHeight(7)),
            ElevatedButton.icon(
              label: Icon(Icons.add, size: ScreenUtil().setSp(18)),
              icon: Text(
                buttonText ?? "",
                style: TextStyle(fontSize: ScreenUtil().setSp(14)),
              ),
              onPressed: () async {
                if (onTap != null) {
                  await onTap!();
                }
                List<String?>? _itens = await showBottomSheetCheckboxIten(
                  context,
                  list: suggestions,
                  title: bottomSheetLabelText ?? "",
                  listSelected: initialValue,
                  forceMenu: forceMenu,
                );
                if (_itens != null) {
                  onChanged!(_itens);
                }
              },
            ),
          ],
        )
      ],
    );
  }
}

==> 1.13.0.tar.gz: lib/src/core/widgets/filters/ModernFormFilterWithCheckboxIten.dart <==
part of modern_form_core;

class ModernFormFilterWithCheckboxIten<T> extends StatelessWidget {
  final String? bottomSheetLabelText;
  final String? buttonText;
  final Future<void> Function()? onTap;
  final bool? forceMenu;
  final bool? moveEnable;

  final List<ModernFormBottomSheetModel<T>> suggestions;
  final List<ModernFormBottomSheetModel<T>>? value;
  final void Function(List<T>)? onChanged;

  const ModernFormFilterWithCheckboxIten({
    Key? key,
    required this.suggestions,
    this.bottomSheetLabelText,
    this.onChanged,
    this.value,
    this.buttonText,
    this.onTap,
    this.forceMenu,
    this.moveEnable,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    bool _moveEnable = moveEnable != null && moveEnable!;
    return Column(
      children: <Widget>[
        Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: <Widget>[
            ModernFormFilterTextListItens(
              itens: value?.map((e) => e.text).toList() ?? <String>[],
              iconData: _moveEnable ? Icons.edit : null,
              onTapCloseIten: (index, c) async {
                List<ModernFormBottomSheetModel<T>> _s =
                    List<ModernFormBottomSheetModel<T>>.from(value!);

                if (_moveEnable) {
                  SecondOption? option = await showSecondOption(
                      c, [SecondOption.Move, SecondOption.Delete]);

                  if (option != null) {
                    switch (option) {
                      case SecondOption.Delete:
                        _s.removeAt(index);
                        break;
                      case SecondOption.Move:
                        int? newIndex =
                            await showMoveTo(c, (value?.length ?? 0), index);
                        if (newIndex != null) {
                          ModernFormBottomSheetModel<T> iten = _s[index];
                          _s.removeAt(index);
                          _s.insert(newIndex, iten);
                        }
                        break;
                      default:
                        break;
                    }
                  }
                } else {
                  _s.removeAt(index);
                }
                if (onChanged != null) {
                  onChanged!(_s.map((e) => e.value).toList());
                }
              },
            ),
            SizedBox(height: ScreenUtil().setHeight(7)),
            ElevatedButton.icon(
              label: Icon(Icons.add, size: ScreenUtil().setSp(18)),
              icon: Text(
                buttonText ?? "",
                style: TextStyle(fontSize: ScreenUtil().setSp(14)),
              ),
              onPressed: () async {
                if (onTap != null) {
                  await onTap!();
                }
                List<T>? _itens = await showBottomSheetCheckboxIten(
                  context,
                  suggestions: suggestions,
                  value: value,
                  title: bottomSheetLabelText ?? "",
                  forceMenu: forceMenu,
                );
                if (_itens != null && onChanged != null) {
                  onChanged!(_itens);
                }
              },
            ),
          ],
        )
      ],
    );
  }
}
